@@ -10,7 +10,7 @@ class HistoryExport:
         'end_at': None,     # date-time - End date/time of export range.
         'status': None,     # string - Status of export.  Will be: `building`, `ready`, or `failed`
         'query_action': None,     # string - Filter results by this this action type. Valid values: `create`, `read`, `update`, `destroy`, `move`, `login`, `failedlogin`, `copy`, `user_create`, `user_update`, `user_destroy`, `group_create`, `group_update`, `group_destroy`, `permission_create`, `permission_destroy`, `api_key_create`, `api_key_update`, `api_key_destroy`
-        'query_interface': None,     # string - Filter results by this this interface type. Valid values: `web`, `ftp`, `robot`, `jsapi`, `webdesktopapi`, `sftp`, `dav`, `desktop`, `restapi`, `scim`, `office`
+        'query_interface': None,     # string - Filter results by this this interface type. Valid values: `web`, `ftp`, `robot`, `jsapi`, `webdesktopapi`, `sftp`, `dav`, `desktop`, `restapi`, `scim`, `office`, `mobile`
         'query_user_id': None,     # string - Return results that are actions performed by the user indiciated by this User ID
         'query_file_id': None,     # string - Return results that are file actions related to the file indicated by this File ID
         'query_parent_id': None,     # string - Return results that are file actions inside the parent folder specified by this folder ID
@@ -78,7 +78,7 @@ def get(id, params = None, options = None):
 #   start_at - string - Start date/time of export range.
 #   end_at - string - End date/time of export range.
 #   query_action - string - Filter results by this this action type. Valid values: `create`, `read`, `update`, `destroy`, `move`, `login`, `failedlogin`, `copy`, `user_create`, `user_update`, `user_destroy`, `group_create`, `group_update`, `group_destroy`, `permission_create`, `permission_destroy`, `api_key_create`, `api_key_update`, `api_key_destroy`
-#   query_interface - string - Filter results by this this interface type. Valid values: `web`, `ftp`, `robot`, `jsapi`, `webdesktopapi`, `sftp`, `dav`, `desktop`, `restapi`, `scim`, `office`
+#   query_interface - string - Filter results by this this interface type. Valid values: `web`, `ftp`, `robot`, `jsapi`, `webdesktopapi`, `sftp`, `dav`, `desktop`, `restapi`, `scim`, `office`, `mobile`
 #   query_user_id - string - Return results that are actions performed by the user indiciated by this User ID
 #   query_file_id - string - Return results that are file actions related to the file indicated by this File ID
 #   query_parent_id - string - Return results that are file actions inside the parent folder specified by this folder ID
