@@ -58,7 +58,7 @@ class User:
         'change_password_confirmation': None,     # string - Optional, but if provided, we will ensure that it matches the value sent in `change_password`.
         'grant_permission': None,     # string - Permission to grant on the user root.  Can be blank or `full`, `read`, `write`, `list`, or `history`.
         'group_id': None,     # int64 - Group ID to associate this user with.
-        'imported_password_hash': None,     # string - Pre-calculated hash of the user's password.
+        'imported_password_hash': None,     # string - Pre-calculated hash of the user's password. If supplied, this will be used to authenticate the user on first login. Supported hash menthods are MD5, SHA1, and SHA256.
         'password': None,     # string - User password.
         'password_confirmation': None,     # string - Optional, but if provided, we will ensure that it matches the value sent in `password`.
         'announcements_read': None,     # boolean - Signifies that the user has read all the announcements in the UI.
@@ -136,7 +136,7 @@ class User:
     #   grant_permission - string - Permission to grant on the user root.  Can be blank or `full`, `read`, `write`, `list`, or `history`.
     #   group_id - int64 - Group ID to associate this user with.
     #   group_ids - string - A list of group ids to associate this user with.  Comma delimited.
-    #   imported_password_hash - string - Pre-calculated hash of the user's password.
+    #   imported_password_hash - string - Pre-calculated hash of the user's password. If supplied, this will be used to authenticate the user on first login. Supported hash menthods are MD5, SHA1, and SHA256.
     #   password - string - User password.
     #   password_confirmation - string - Optional, but if provided, we will ensure that it matches the value sent in `password`.
     #   announcements_read - boolean - Signifies that the user has read all the announcements in the UI.
@@ -340,7 +340,7 @@ def get(id, params = None, options = None):
 #   grant_permission - string - Permission to grant on the user root.  Can be blank or `full`, `read`, `write`, `list`, or `history`.
 #   group_id - int64 - Group ID to associate this user with.
 #   group_ids - string - A list of group ids to associate this user with.  Comma delimited.
-#   imported_password_hash - string - Pre-calculated hash of the user's password.
+#   imported_password_hash - string - Pre-calculated hash of the user's password. If supplied, this will be used to authenticate the user on first login. Supported hash menthods are MD5, SHA1, and SHA256.
 #   password - string - User password.
 #   password_confirmation - string - Optional, but if provided, we will ensure that it matches the value sent in `password`.
 #   announcements_read - boolean - Signifies that the user has read all the announcements in the UI.
@@ -485,7 +485,7 @@ def user_2fa_reset(id, params = None, options = None):
 #   grant_permission - string - Permission to grant on the user root.  Can be blank or `full`, `read`, `write`, `list`, or `history`.
 #   group_id - int64 - Group ID to associate this user with.
 #   group_ids - string - A list of group ids to associate this user with.  Comma delimited.
-#   imported_password_hash - string - Pre-calculated hash of the user's password.
+#   imported_password_hash - string - Pre-calculated hash of the user's password. If supplied, this will be used to authenticate the user on first login. Supported hash menthods are MD5, SHA1, and SHA256.
 #   password - string - User password.
 #   password_confirmation - string - Optional, but if provided, we will ensure that it matches the value sent in `password`.
 #   announcements_read - boolean - Signifies that the user has read all the announcements in the UI.
